@@ -1,9 +1,7 @@
 my (undef, $dir) = app->presentation_file;
 
 my $conf = {
-  slides => {
-    list => ['hello', 'goodbye'],
-  },
+  slides => ['hello', 'goodbye'],
   bootstrap_theme => 1,
   templates => $dir,
 };
