@@ -2,11 +2,13 @@ package App::MojoSlides;
 
 use Mojo::Base 'Mojolicious';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 $VERSION = eval $VERSION;
 
 use App::MojoSlides::Slides;
 
+use Mojo::File;
+
 has slides => sub {
   my $self = shift;
   return App::MojoSlides::Slides->new( 
@@ -116,7 +118,7 @@ sub _column {
 sub include_data_handle_from_file {
   my ($self, $file) = @_;
   require Mojo::Util;
-  my $string = Mojo::Util::slurp($file);
+  my $string = Mojo::File->new($file)->slurp;
   open my $handle, '<', \$string;
   while (<$handle>) {
     last if /^__DATA__/; # seek to __DATA__
@@ -137,7 +139,7 @@ __END__
 
 =head1 NAME
 
-App::MojoSlides - Write your presentations in Perl and Mojolicious!
+App::MojoSlides - DEPRECATED Write your presentations in Perl and Mojolicious!
 
 =head1 SYNOPSIS
 
@@ -153,6 +155,14 @@ in structure and usage, though it is not nearly as full featured.
 
 This software is in alpha form at best. It may eat baby kittens at any moment.
 
+Indeed it never really got better than this, that's why:
+
+=head1 DEPRECATED
+
+This module is now officially deprecated.
+I will give it no further effort.
+If someone would like to adopt it, please contact me.
+
 =head1 USAGE
 
 =head2 The Presentation File
